@@ -24,7 +24,6 @@ class CControllerExport extends CController {
 		$fields = [
 			'action' =>			'required|string',
 			'backurl' =>		'required|string',
-			'valuemapids' =>	'not_empty|array_db valuemaps.valuemapid',
 			'hostids' =>		'not_empty|array_db hosts.hostid',
 			'mediatypeids' =>	'not_empty|array_db media_type.mediatypeid',
 			'maps' =>			'not_empty|array_db sysmaps.sysmapid',
@@ -46,9 +45,6 @@ class CControllerExport extends CController {
 			case 'export.mediatypes':
 				return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_MEDIA_TYPES);
 
-			case 'export.valuemaps':
-				return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_GENERAL);
-
 			case 'export.hosts':
 				return $this->checkAccess(CRoleHelper::UI_CONFIGURATION_HOSTS);
 
@@ -72,10 +68,6 @@ class CControllerExport extends CController {
 		];
 
 		switch ($action) {
-			case 'export.valuemaps':
-				$params['options']['valueMaps'] = $this->getInput('valuemapids', []);
-				break;
-
 			case 'export.hosts':
 				$params['options']['hosts'] = $this->getInput('hostids', []);
 				break;
