@@ -1,21 +1,16 @@
-<?php
+<?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -24,15 +19,15 @@
  */
 class CControllerModuleScan extends CController {
 
-	protected function checkInput() {
+	protected function checkInput(): bool {
 		return true;
 	}
 
-	protected function checkPermissions() {
+	protected function checkPermissions(): bool {
 		return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_GENERAL);
 	}
 
-	protected function doAction() {
+	protected function doAction(): void {
 		get_and_clear_messages();
 
 		$db_modules_create = [];
@@ -53,36 +48,38 @@ class CControllerModuleScan extends CController {
 			$db_moduleids[$db_module['relative_path']] = $moduleid;
 		}
 
-		$module_manager = new CModuleManager(APP::ModuleManager()->getModulesDir());
+		$module_manager = new CModuleManager(APP::getRootDir());
 
-		foreach (new DirectoryIterator($module_manager->getModulesDir()) as $item) {
-			if (!$item->isDir() || $item->isDot()) {
-				continue;
-			}
+		foreach (['widgets', 'modules'] as $modules_dir) {
+			foreach (new DirectoryIterator(APP::getRootDir().'/'.$modules_dir) as $item) {
+				if (!$item->isDir() || $item->isDot()) {
+					continue;
+				}
 
-			$relative_path = $item->getFilename();
+				$relative_path = $modules_dir.'/'.$item->getFilename();
 
-			$manifest = $module_manager->addModule($relative_path);
+				$manifest = $module_manager->addModule($relative_path);
 
-			if (!$manifest) {
-				continue;
-			}
+				if (!$manifest) {
+					continue;
+				}
 
-			$is_stored = array_key_exists($relative_path, $db_moduleids);
-			$is_healthy = !$is_stored || $db_modules[$db_moduleids[$relative_path]]['id'] === $manifest['id'];
+				$is_stored = array_key_exists($relative_path, $db_moduleids);
+				$is_healthy = !$is_stored || $db_modules[$db_moduleids[$relative_path]]['id'] === $manifest['id'];
 
-			if ($is_healthy) {
-				$healthy_modules[] = $relative_path;
-			}
+				if ($is_healthy) {
+					$healthy_modules[] = $relative_path;
+				}
 
-			if (!$is_stored || !$is_healthy) {
-				$db_modules_create[] = [
-					'id' => $manifest['id'],
-					'relative_path' => $relative_path,
-					'status' => MODULE_STATUS_DISABLED,
-					'config' => $manifest['config']
-				];
-				$db_modules_create_names[] = $manifest['name'];
+				if (!$is_stored || !$is_healthy) {
+					$db_modules_create[] = [
+						'id' => $manifest['id'],
+						'relative_path' => $relative_path,
+						'status' => MODULE_STATUS_DISABLED,
+						'config' => $manifest['config']
+					];
+					$db_modules_create_names[] = $manifest['name'];
+				}
 			}
 		}
 
@@ -127,13 +124,14 @@ class CControllerModuleScan extends CController {
 			? _('Modules updated')
 			: _('No new modules discovered');
 
-		if (hasErrorMesssages()) {
+		if (hasErrorMessages()) {
 			CMessageHelper::setErrorTitle($message);
 		}
 		else {
 			CMessageHelper::setSuccessTitle($message);
 		}
 
+		$response->setFormData(['uncheck' => '1']);
 		$this->setResponse($response);
 	}
 }
