@@ -108,11 +108,18 @@ foreach ($data['scripts'] as $script) {
 				$action_count_total = (new CSpan($script['action_count_total']))->addClass(ZBX_STYLE_ENTITY_COUNT);
 
 				foreach ($script['actions'] as $action) {
+					$action_url = (new CUrl('zabbix.php'))
+						->setArgument('action', 'popup')
+						->setArgument('popup', 'action.edit')
+						->setArgument('actionid', $action['actionid'])
+						->setArgument('eventsource', $action['eventsource'])
+						->getUrl();
+
 					$actions[] = $action['is_editable']
-						? (new CLink($action['name']))
-							->addClass('js-action-edit')
+						? (new CLink($action['name'], $action_url))
 							->setAttribute('data-actionid', $action['actionid'])
 							->setAttribute('data-eventsource', $action['eventsource'])
+							->setAttribute('data-action', 'action.edit')
 							->addClass(ZBX_STYLE_LINK_ALT)
 							->addClass(ZBX_STYLE_GREY)
 						: (new CSpan($action['name']))->addClass(ZBX_STYLE_GREY);
@@ -181,9 +188,15 @@ foreach ($data['scripts'] as $script) {
 		$execute_on = '';
 	}
 
-	$link = (new CLink($script['name']))
-		->addClass('js-edit')
-		->setAttribute('data-scriptid', $script['scriptid']);
+	$script_url = (new CUrl('zabbix.php'))
+		->setArgument('action', 'popup')
+		->setArgument('popup', 'script.edit')
+		->setArgument('scriptid', $script['scriptid'])
+		->getUrl();
+
+	$link = (new CLink($script['name'], $script_url))
+		->setAttribute('data-scriptid', $script['scriptid'])
+		->setAttribute('data-action', 'script.edit');
 
 	$scriptsTable->addRow([
 		new CCheckBox('scriptids['.$script['scriptid'].']', $script['scriptid']),
