@@ -32,9 +32,9 @@ class CMediatype extends CApiService {
 
 	public const OUTPUT_FIELDS = ['mediatypeid', 'type', 'name', 'smtp_server', 'smtp_helo', 'smtp_email',
 		'exec_path', 'gsm_modem', 'username', 'passwd', 'status', 'smtp_port', 'smtp_security', 'smtp_verify_peer',
-		'smtp_verify_host', 'smtp_authentication', 'maxsessions', 'maxattempts', 'attempt_interval', 'content_type',
-		'message_format', 'script', 'timeout', 'process_tags', 'show_event_menu', 'event_menu_url', 'event_menu_name',
-		'description', 'provider', 'parameters'
+		'smtp_verify_host', 'smtp_authentication', 'maxsessions', 'maxattempts', 'attempt_interval', 'message_format',
+		'script', 'timeout', 'process_tags', 'show_event_menu', 'event_menu_url', 'event_menu_name', 'description',
+		'provider', 'parameters'
 	];
 
 	public const LIMITED_OUTPUT_FIELDS = ['mediatypeid', 'type', 'name', 'status', 'description', 'maxattempts'];
@@ -64,15 +64,11 @@ class CMediatype extends CApiService {
 			'userids'					=> null,
 			'editable'					=> false,
 			// filter
-			'filter'					=> null,
-			'search'					=> null,
 			'searchByAny'				=> null,
 			'startSearch'				=> false,
 			'excludeSearch'				=> false,
 			'searchWildcardsEnabled'	=> null,
 			// output
-			'output'					=> API_OUTPUT_EXTEND,
-			'selectMessageTemplates'	=> null,
 			'selectUsers'				=> null,
 			'countOutput'				=> false,
 			'groupCount'				=> false,
@@ -84,31 +80,35 @@ class CMediatype extends CApiService {
 
 		$options = zbx_array_merge($defOptions, $options);
 
-		if (!$options['countOutput'] && is_array($options['output']) && in_array('content_type', $options['output'])) {
-			self::deprecated('Field "content_type" is deprecated.');
+		// permission check
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && $options['editable']) {
+			return [];
 		}
 
+		$output_fields = self::$userData['type'] == USER_TYPE_SUPER_ADMIN
+			? self::OUTPUT_FIELDS
+			: self::LIMITED_OUTPUT_FIELDS;
+
 		$api_input_rules = ['type' => API_OBJECT, 'flags' => API_ALLOW_UNEXPECTED, 'fields' => [
-			'selectActions' =>  ['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', CAction::OUTPUT_FIELDS), 'default' => null]
+			// filter
+			'filter' =>					['type' => API_FILTER, 'flags' => API_ALLOW_NULL, 'default' => null, 'fields' => DB::getFilterFields('media_type', $output_fields)],
+			'search' =>					['type' => API_FILTER, 'flags' => API_ALLOW_NULL, 'default' => null, 'fields' => DB::getSearchFields('media_type', $output_fields)],
+
+			// output
+			'output' =>					['type' => API_OUTPUT, 'in' => implode(',', $output_fields), 'default' => API_OUTPUT_EXTEND],
+			'selectMessageTemplates' =>	['type' => API_MULTIPLE, 'rules' => [
+											['if' => static fn(): bool => self::$userData['type'] == USER_TYPE_SUPER_ADMIN, 'type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', ['eventsource', 'recovery', 'subject', 'message']), 'default' => null],
+											['else' => true, 'type' => API_UNEXPECTED]
+			]],
+			'selectActions' =>  		['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', CAction::OUTPUT_FIELDS), 'default' => null]
 		]];
 
 		if (!CApiInputValidator::validate($api_input_rules, $options, '/', $error)) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		// permission check
-		if ((self::$userData['type'] == USER_TYPE_ZABBIX_ADMIN && $options['editable'])
-				|| self::$userData['type'] == USER_TYPE_ZABBIX_USER) {
-			return [];
-		}
-
-		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
-			if ($options['output'] === API_OUTPUT_EXTEND) {
-				$options['output'] = self::LIMITED_OUTPUT_FIELDS;
-			}
-			elseif (is_array($options['output'])) {
-				$options['output'] = array_intersect($options['output'], self::LIMITED_OUTPUT_FIELDS);
-			}
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && $options['output'] === API_OUTPUT_EXTEND) {
+			$options['output'] = self::LIMITED_OUTPUT_FIELDS;
 		}
 
 		// mediatypeids
@@ -150,32 +150,12 @@ class CMediatype extends CApiService {
 		}
 
 		// filter
-		if (is_array($options['filter'])) {
-			if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
-				if ($options['searchByAny'] !== null && $options['searchByAny'] !== false) {
-					$options['filter'] =
-						array_intersect_key($options['filter'], array_flip(self::LIMITED_OUTPUT_FIELDS));
-				}
-				elseif (array_diff_key($options['filter'], array_flip(self::LIMITED_OUTPUT_FIELDS))) {
-					return [];
-				}
-			}
-
+		if ($options['filter'] !== null) {
 			$this->dbFilter('media_type mt', $options, $sqlParts);
 		}
 
 		// search
-		if (is_array($options['search'])) {
-			if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
-				if ($options['searchByAny']) {
-					$options['search'] =
-						array_intersect_key($options['search'], array_flip(self::LIMITED_OUTPUT_FIELDS));
-				}
-				elseif (array_diff_key($options['search'], array_flip(self::LIMITED_OUTPUT_FIELDS))) {
-					return [];
-				}
-			}
-
+		if ($options['search'] !== null) {
 			zbx_db_search('media_type mt', $options, $sqlParts);
 		}
 
@@ -188,13 +168,6 @@ class CMediatype extends CApiService {
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 
-		if (!$options['countOutput']) {
-			$add_content_type = $options['output'] === API_OUTPUT_EXTEND
-				|| in_array('content_type', $options['output']);
-			$remove_message_format = $options['output'] !== API_OUTPUT_EXTEND
-				&& !in_array('message_format', $options['output']);
-		}
-
 		while ($mediatype = DBfetch($res)) {
 			if ($options['countOutput']) {
 				if ($options['groupCount']) {
@@ -205,13 +178,6 @@ class CMediatype extends CApiService {
 				}
 			}
 			else {
-				if ($add_content_type) {
-					$mediatype['content_type'] = $mediatype['message_format'];
-					if ($remove_message_format) {
-						unset($mediatype['message_format']);
-					}
-				}
-
 				$result[$mediatype['mediatypeid']] = $mediatype;
 			}
 		}
@@ -222,7 +188,7 @@ class CMediatype extends CApiService {
 
 		if ($result) {
 			$result = $this->addRelatedObjects($options, $result);
-			$result = $this->unsetExtraFields($result, ['type'], $options['output']);
+			$result = $this->unsetExtraFields($result, ['mediatypeid', 'type'], $options['output']);
 		}
 
 		if (!$options['preservekeys']) {
@@ -285,11 +251,9 @@ class CMediatype extends CApiService {
 			'smtp_verify_host' =>		['type' => API_INT32],
 			'smtp_authentication' =>	['type' => API_INT32],
 			'provider' =>				['type' => API_INT32, 'in' => implode(',', array_keys(CMediatypeHelper::getEmailProviders()))],
-			'exec_params' =>			['type' => API_STRING_UTF8, 'flags' => API_DEPRECATED],
 			'maxsessions' =>			['type' => API_INT32],
 			'maxattempts' =>			['type' => API_INT32, 'in' => '1:100'],
 			'attempt_interval' =>		['type' => API_TIME_UNIT, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('media_type', 'attempt_interval'), 'in' => '0:'.SEC_PER_HOUR],
-			'content_type' =>			['type' => API_INT32, 'flags' => API_DEPRECATED, 'replacement' => 'message_format'],
 			'message_format' =>			['type' => API_INT32],
 			'script' =>					['type' => API_STRING_UTF8],
 			'timeout' =>				['type' => API_TIME_UNIT],
@@ -387,11 +351,9 @@ class CMediatype extends CApiService {
 			'smtp_verify_host' =>		['type' => API_INT32],
 			'smtp_authentication' =>	['type' => API_INT32],
 			'provider' =>				['type' => API_INT32, 'in' => implode(',', array_keys(CMediatypeHelper::getEmailProviders()))],
-			'exec_params' =>			['type' => API_STRING_UTF8, 'flags' => API_DEPRECATED],
 			'maxsessions' =>			['type' => API_INT32],
 			'maxattempts' =>			['type' => API_INT32, 'in' => '1:100'],
 			'attempt_interval' =>		['type' => API_TIME_UNIT, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('media_type', 'attempt_interval'), 'in' => '0:'.SEC_PER_HOUR],
-			'content_type' =>			['type' => API_INT32, 'flags' => API_DEPRECATED, 'replacement' => 'message_format'],
 			'message_format' =>			['type' => API_INT32],
 			'script' =>					['type' => API_STRING_UTF8],
 			'timeout' =>				['type' => API_TIME_UNIT],
@@ -495,7 +457,7 @@ class CMediatype extends CApiService {
 					'smtp_verify_host', 'smtp_authentication', 'username', 'passwd', 'message_format', 'provider'
 				],
 				MEDIA_TYPE_EXEC => [
-					'exec_path', 'exec_params', 'parameters'
+					'exec_path', 'parameters'
 				],
 				MEDIA_TYPE_SMS => [
 					'gsm_modem', 'maxsessions'
@@ -524,18 +486,6 @@ class CMediatype extends CApiService {
 				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 			}
 
-			if (array_key_exists('exec_params', $mediatype)) {
-				if ($type == MEDIA_TYPE_EXEC && !array_key_exists('parameters', $mediatype)) {
-					$parameters = explode("\n", trim($mediatype['exec_params']));
-
-					foreach ($parameters as $sortorder => $value) {
-						$mediatype['parameters'][] = ['sortorder' => $sortorder, 'value' => $value];
-					}
-				}
-
-				unset($mediatype['exec_params']);
-			}
-
 			if ($method === 'update') {
 				switch ($type) {
 					case MEDIA_TYPE_EMAIL:
@@ -898,21 +848,40 @@ class CMediatype extends CApiService {
 
 		$db_mediatypes = DB::select('media_type', [
 			'output' => ['mediatypeid', 'name'],
-			'mediatypeids' => $mediatypeids
+			'mediatypeids' => $mediatypeids,
+			'preservekeys' => true
 		]);
 
 		if (count($db_mediatypes) != count($mediatypeids)) {
 			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
 		}
 
-		$actions = API::Action()->get([
-			'output' => ['name'],
+		$db_actions = API::Action()->get([
+			'output' => ['actionid', 'name'],
 			'mediatypeids' => $mediatypeids,
 			'limit' => 1
 		]);
 
-		if ($actions) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _s('Media types used by action "%1$s".', $actions[0]['name']));
+		if ($db_actions) {
+			$db_action_operations = API::Action()->get([
+				'output' => [],
+				'selectOperations' => ['opmessage'],
+				'selectRecoveryOperations' => ['opmessage'],
+				'selectUpdateOperations' => ['opmessage'],
+				'actionids' => $db_actions[0]['actionid']
+			]);
+
+			foreach (['operations', 'recovery_operations', 'update_operations'] as $operations) {
+				foreach ($db_action_operations[0][$operations] as $operation) {
+					if (array_key_exists('opmessage', $operation)
+							&& array_key_exists($operation['opmessage']['mediatypeid'], $db_mediatypes)) {
+						self::exception(ZBX_API_ERROR_PARAMETERS, _s('Media type "%1$s" is used by action "%2$s".',
+							$db_mediatypes[$operation['opmessage']['mediatypeid']]['name'],
+							$db_actions[0]['name']
+						));
+					}
+				}
+			}
 		}
 
 		DB::delete('media_type', ['mediatypeid' => $mediatypeids]);
@@ -923,16 +892,6 @@ class CMediatype extends CApiService {
 	}
 
 	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts): array {
-		if (!$options['countOutput'] && is_array($options['output'])
-				&& ($i = array_search('content_type', $options['output'])) !== false) {
-			if (in_array('message_format', $options['output'])) {
-				unset($options['output'][$i]);
-			}
-			else {
-				$options['output'][$i] = 'message_format';
-			}
-		}
-
 		$sqlParts = parent::applyQueryOutputOptions($tableName, $tableAlias, $options, $sqlParts);
 
 		if (!$options['countOutput'] && $this->outputIsRequested('parameters', $options['output'])) {
@@ -948,8 +907,7 @@ class CMediatype extends CApiService {
 		self::addRelatedActions($options, $result);
 
 		// adding message templates
-		if (self::$userData['type'] == USER_TYPE_SUPER_ADMIN && $options['selectMessageTemplates'] !== null
-				&& $options['selectMessageTemplates'] != API_OUTPUT_COUNT) {
+		if (array_key_exists('selectMessageTemplates', $options) && $options['selectMessageTemplates'] !== null) {
 			$message_templates = [];
 
 			$relation_map = $this->createRelationMap($result, 'mediatypeid', 'mediatype_messageid',
@@ -1103,7 +1061,7 @@ class CMediatype extends CApiService {
 			'SELECT DISTINCT om.mediatypeid,o.actionid'.
 			' FROM opmessage om,operations o'.
 			' WHERE om.operationid=o.operationid'.
-			' AND ('.dbConditionId('om.mediatypeid', array_keys($result)).' OR om.mediatypeid IS NULL)'
+				' AND ('.dbConditionId('om.mediatypeid', array_keys($result)).' OR om.mediatypeid IS NULL)'
 		);
 
 		$action_mediatypeids = [];
@@ -1111,30 +1069,28 @@ class CMediatype extends CApiService {
 		while ($row = DBfetch($db_action_mediatypes)) {
 			if ($row['mediatypeid'] == 0) {
 				foreach ($result as $mediatype) {
-					$action_mediatypeids[$row['actionid']][$mediatype['mediatypeid']] = $mediatype['mediatypeid'];
+					$action_mediatypeids[$row['actionid']][$mediatype['mediatypeid']] = true;
 				}
 			}
 			else {
-				$action_mediatypeids[$row['actionid']][$row['mediatypeid']] = $row['mediatypeid'];
+				$action_mediatypeids[$row['actionid']][$row['mediatypeid']] = true;
 			}
 		}
 
-		$action_options = [
+		$actions = API::Action()->get([
 			'output' => $options['selectActions'],
-			'actionids' => array_keys($action_mediatypeids)
-		];
-
-		$db_actions = DBselect(DB::makeSql('actions', $action_options));
+			'actionids' => array_keys($action_mediatypeids),
+			'sortfield' => 'name',
+			'preservekeys' => true
+		]);
 
 		foreach ($result as $mediatype) {
 			$result[$mediatype['mediatypeid']]['actions'] = [];
 		}
 
-		while ($action = DBfetch($db_actions)) {
-			foreach ($action_mediatypeids[$action['actionid']] as $mediatypeid) {
+		foreach ($actions as $actionid => $action) {
+			foreach ($action_mediatypeids[$actionid] as $mediatypeid => $foo) {
 				$result[$mediatypeid]['actions'][] = $action;
-
-				CArrayHelper::sort($result[$mediatypeid]['actions'], ['name']);
 			}
 		}
 	}
