@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -91,51 +86,56 @@ class CXmlExportWriter extends CExportWriter {
 	 */
 	private function mapName($name) {
 		$map = [
-			'groups' => 'group',
-			'templates' => 'template',
-			'hosts' => 'host',
-			'interfaces' => 'interface',
-			'applications' => 'application',
-			'items' => 'item',
-			'discovery_rules' => 'discovery_rule',
 			'conditions' => 'condition',
-			'item_prototypes' => 'item_prototype',
-			'application_prototypes' => 'application_prototype',
-			'trigger_prototypes' => 'trigger_prototype',
+			'dashboards' => 'dashboard',
+			'dependencies' => 'dependency',
+			'discovery_rules' => 'discovery_rule',
+			'elements' => 'element',
+			'fields' => 'field',
+			'graph_items' => 'graph_item',
 			'graph_prototypes' => 'graph_prototype',
-			'host_prototypes' => 'host_prototype',
+			'graphs' => 'graph',
 			'group_links' => 'group_link',
 			'group_prototypes' => 'group_prototype',
-			'triggers' => 'trigger',
-			'dependencies' => 'dependency',
-			'screen_items' => 'screen_item',
-			'macros' => 'macro',
-			'screens' => 'screen',
+			'host_groups' => 'host_group',
+			'template_groups' => 'template_group',
+			'groups' => 'group',
+			'headers' => 'header',
+			'host_prototypes' => 'host_prototype',
+			'hosts' => 'host',
+			'httptests' => 'httptest',
 			'images' => 'image',
-			'graphs' => 'graph',
-			'graph_items' => 'graph_item',
-			'maps' => 'map',
-			'urls' => 'url',
-			'selements' => 'selement',
-			'elements' => 'element',
+			'interfaces' => 'interface',
+			'item_prototypes' => 'item_prototype',
+			'items' => 'item',
+			'lines' => 'line',
 			'links' => 'link',
 			'linktriggers' => 'linktrigger',
-			'value_maps' => 'value_map',
+			'lld_macro_paths' => 'lld_macro_path',
+			'macros' => 'macro',
 			'mappings' => 'mapping',
-			'httptests' => 'httptest',
+			'maps' => 'map',
+			'media_types' => 'media_type',
+			'message_templates' => 'message_template',
+			'operations' => 'operation',
+			'overrides' => 'override',
+			'pages' => 'page',
+			'parameters' => 'parameter',
+			'posts' => 'post_field',
+			'preprocessing' => 'step',
+			'query_fields' => 'query_field',
+			'selements' => 'selement',
+			'shapes' => 'shape',
 			'steps' => 'step',
 			'tags' => 'tag',
-			'preprocessing' => 'step',
-			'headers' => 'header',
-			'variables' => 'variable',
-			'query_fields' => 'query_field',
-			'posts' => 'post_field',
-			'shapes' => 'shape',
-			'lines' => 'line',
-			'lld_macro_paths' => 'lld_macro_path',
+			'templates' => 'template',
 			'tls_accept' => 'option',
-			'media_types' => 'media_type',
-			'parameters' => 'parameter'
+			'trigger_prototypes' => 'trigger_prototype',
+			'triggers' => 'trigger',
+			'urls' => 'url',
+			'valuemaps' => 'valuemap',
+			'variables' => 'variable',
+			'widgets' => 'widget'
 		];
 
 		return isset($map[$name]) ? $map[$name] : false;
