@@ -23,20 +23,18 @@ class CWidgetFieldThresholdsView extends CWidgetFieldView {
 	}
 
 	public function getView(): CDiv {
-		$header_row = [
-			'',
-			(new CColHeader(_('Threshold')))->setWidth('100%'),
-			_('Action')
-		];
-
 		$thresholds_table = (new CTable())
 			->setId($this->field->getName().'-table')
 			->addClass(ZBX_STYLE_TABLE_FORMS)
-			->setHeader($header_row)
+			->setHeader([
+				'',
+				_('Threshold'),
+				(new CColHeader(''))->setWidth('100%')
+			])
 			->setFooter(new CRow(
-				(new CCol(
+				new CCol(
 					(new CButtonLink(_('Add')))->addClass('element-table-add')
-				))->setColSpan(count($header_row))
+				)
 			));
 
 		foreach ($this->field->getValue() as $i => $threshold) {
