@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -224,7 +219,8 @@ function getMenuPopupHost(options, trigger_element) {
 		if (options.allowed_ui_conf_hosts) {
 			// host
 			url = new Curl('zabbix.php');
-			url.setArgument('action', 'host.edit');
+			url.setArgument('action', 'popup');
+			url.setArgument('popup', 'host.edit');
 			url.setArgument('hostid', options.hostid);
 
 			configuration.push({
@@ -234,13 +230,16 @@ function getMenuPopupHost(options, trigger_element) {
 				clickCallback: function(e) {
 					e.preventDefault();
 					jQuery(this).closest('.menu-popup').menuPopup('close', null);
-
-					view.editHost(options.hostid);
+				},
+				dataAttributes: {
+					action: 'host.edit',
+					hostid: options.hostid
 				}
 			});
 
 			// items
-			url = new Curl('items.php');
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'item.list');
 			url.setArgument('filter_set', '1');
 			url.setArgument('filter_hostids[]', options.hostid);
 			url.setArgument('context', 'host');
@@ -252,7 +251,8 @@ function getMenuPopupHost(options, trigger_element) {
 			});
 
 			// triggers
-			url = new Curl('triggers.php');
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'trigger.list');
 			url.setArgument('filter_set', '1');
 			url.setArgument('filter_hostids[]', options.hostid);
 			url.setArgument('context', 'host');
@@ -310,7 +310,7 @@ function getMenuPopupHost(options, trigger_element) {
 	if ('urls' in options) {
 		sections.push({
 			label: t('Links'),
-			items: getMenuPopupURLData(options.urls, trigger_element)
+			items: getMenuPopupURLData(options.urls, trigger_element, options.hostid, null)
 		});
 	}
 
@@ -319,7 +319,8 @@ function getMenuPopupHost(options, trigger_element) {
 		sections.push({
 			label: t('Scripts'),
 			items: getMenuPopupScriptData(options.scripts, trigger_element, options.hostid, options.eventid,
-				options.csrf_token)
+				options.csrf_token
+			)
 		});
 	}
 
@@ -474,7 +475,7 @@ function getMenuPopupMapElementTrigger(options) {
 
 		items.push({
 			label: t('Problems'),
-			disabled: !options.showEvents,
+			disabled: !options.show_events,
 			url: url.getUrl()
 		});
 	}
@@ -492,7 +493,7 @@ function getMenuPopupMapElementTrigger(options) {
 				label: item.name,
 				url: url.getUrl()
 			});
-		};
+		}
 
 		items.push({
 			label: t('History'),
@@ -514,15 +515,21 @@ function getMenuPopupMapElementTrigger(options) {
 		const item_urls = [];
 
 		for (const value of options.triggers) {
-			url = new Curl('triggers.php');
-			url.setArgument('form', 'update');
-			url.setArgument('triggerid', value.triggerid);
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'popup');
+			url.setArgument('popup', 'trigger.edit');
 			url.setArgument('context', 'host');
+			url.setArgument('triggerid', value.triggerid);
 
 			trigger_urls.push({
 				label: value.description,
-				url: url.getUrl()
-			});
+				url: url.getUrl(),
+				dataAttributes: {
+					action: 'trigger.edit',
+					triggerid: value.triggerid,
+					context: 'host'
+				}
+			})
 		}
 
 		config_urls.push({
@@ -532,17 +539,30 @@ function getMenuPopupMapElementTrigger(options) {
 
 		if (options.items.length) {
 			for (const item of options.items) {
-				url = new Curl('items.php');
-				url.setArgument('form', 'update');
-				url.setArgument('itemid', item.params.itemid);
-				url.setArgument('context', 'host');
+				if (item.params.is_webitem) {
+					item_urls.push({
+						label: item.name,
+						disabled: true
+					});
+				}
+				else {
+					url = new Curl('zabbix.php');
+					url.setArgument('action', 'popup');
+					url.setArgument('popup', 'item.edit');
+					url.setArgument('context', 'host');
+					url.setArgument('itemid', item.params.itemid);
 
-				item_urls.push({
-					label: item.name,
-					disabled: item.params.is_webitem,
-					url: url.getUrl()
-				});
-			};
+					item_urls.push({
+						label: item.name,
+						url: url.getUrl(),
+						dataAttributes: {
+							action: 'item.edit',
+							itemid: item.params.itemid,
+							context: 'host'
+						}
+					});
+				}
+			}
 
 			config_urls.push({
 				label: t('Items'),
@@ -620,7 +640,7 @@ function getMenuPopupDashboard(options, trigger_element) {
 		const url_delete = new Curl('zabbix.php');
 		url_delete.setArgument('action', 'dashboard.delete');
 		url_delete.setArgument('dashboardids', [options.dashboardid]);
-		url_delete.setArgument('_csrf_token', options.csrf_token);
+		url_delete.setArgument(CSRF_TOKEN_NAME, options.csrf_token);
 
 		sections.push({
 			label: t('Actions'),
@@ -655,7 +675,7 @@ function getMenuPopupDashboard(options, trigger_element) {
 							return false;
 						}
 
-						redirect(url_delete.getUrl(), 'post', '_csrf_token', true);
+						redirect(url_delete.getUrl(), 'post', CSRF_TOKEN_NAME, true);
 					},
 					disabled: !options.editable
 				}
@@ -671,7 +691,10 @@ function getMenuPopupDashboard(options, trigger_element) {
 				clickCallback: function () {
 					jQuery(this).closest('.menu-popup').menuPopup('close', null);
 
-					PopUp('popup.scheduledreport.list', parameters, {trigger_element});
+					PopUp('popup.scheduledreport.list', parameters, {
+						dialogue_class: 'modal-popup-generic',
+						trigger_element
+					});
 				},
 				disabled: !options.has_related_reports
 			}
@@ -683,7 +706,10 @@ function getMenuPopupDashboard(options, trigger_element) {
 				clickCallback: function () {
 					jQuery(this).closest('.menu-popup').menuPopup('close', null);
 
-					PopUp('popup.scheduledreport.edit', parameters, {trigger_element});
+					PopUp('popup.scheduledreport.edit', parameters, {
+						dialogue_class: 'modal-popup-generic',
+						trigger_element
+					});
 				}
 			});
 		}
@@ -700,20 +726,31 @@ function getMenuPopupDashboard(options, trigger_element) {
 /**
  * Get menu popup trigger section data.
  *
- * @param {string} options['triggerid']                   Trigger ID.
- * @param {string} options['eventid']                     (optional) Required for "Update problem" section and event
+ * @param {object} options
+ *        {string} options['triggerid']                   Trigger ID.
+ *        {bool}   options['allowed_actions_change_problem_ranking']
+ *                                                        Whether user is allowed to change event rank.
+ *        {bool}   options['allowed_ui_conf_hosts']       Whether user has access to Configuration > Hosts.
+ *        {bool}   options['allowed_ui_latest_data']      Whether user has access to Monitoring > Latest data.
+ *        {bool}   options['allowed_ui_problems']         Whether user has access to Monitoring > Problems.
+ *        {bool}   options['backurl']                     URL from where the menu popup was called.
+ *        {bool}   options['show_events']                 Show Problems item enabled. Default: false.
+ *        {string} options['eventid']                     (optional) Required for "Update problem" section and event
  *                                                        rank change.
- * @param {object} options['items']                       Link to trigger item history page (optional).
- * @param {string} options['items'][]['name']             Item name.
- * @param {object} options['items'][]['params']           Item URL parameters ("name" => "value").
- * @param {bool}   options['update_problem']              (optional) Whether to show "Update problem" section.
- * @param {object} options['configuration']               Link to trigger configuration page (optional).
- * @param {bool}   options['showEvents']                  Show Problems item enabled. Default: false.
- * @param {string} options['url']                         Trigger URL link (optional).
+ *        {array}  options['eventids']                    (optional)
+ *        {array}  options['csrf_tokens']                 (optional) CSRF tokens.
+ *        {string} options['csrf_tokens']['acknowledge']  (optional) CSRF token for acknowledge action.
+ *        {string} options['csrf_tokens']['scriptexec']   (optional) CSRF token for script execution.
+ *        {array}  options['items']                       (optional) Link to trigger item history page.
+ *        {string} options['items'][]['name']             Item name.
+ *        {object} options['items'][]['params']           Item URL parameters ("name" => "value").
+ *        {bool}   options['mark_as_cause']               (optional) Whether to enable "Mark as cause".
+ *        {bool}   options['mark_selected_as_symptoms']   (optional) Whether to enable "Mark selected as symptoms".
+ *        {bool}   options['show_update_problem']         (optional) Whether to show "Update problem".
+ *        {bool}   options['show_rank_change_cause']      (optional) Whether to show "Mark as cause".
+ *        {bool}   options['show_rank_change_symptom']    (optional) Whether to show "Mark selected as symptoms".
+ *        {array}  options['urls']                        (optional) Links.
  * @param {object} trigger_element                        UI element which triggered opening of overlay dialogue.
- * @param {array} options[csrf_tokens][]
- * @param {string} options[csrf_tokens][]['scriptexec']   CSRF token for script execution.
- * @param {string} options[csrf_tokens][]['acknowledge']  CSRF token for acknowledge action.
  *
  * @return array
  */
@@ -731,22 +768,11 @@ function getMenuPopupTrigger(options, trigger_element) {
 
 		items.push({
 			label: t('Problems'),
-			disabled: !options.showEvents,
+			disabled: !options.show_events,
 			url: url.getUrl()
 		});
 	}
 
-	if ('update_problem' in options) {
-		items.push({
-			label: t('Update problem'),
-			clickCallback: function() {
-				jQuery(this).closest('.menu-popup-top').menuPopup('close', null);
-
-				acknowledgePopUp({eventids: [options.eventid]}, trigger_element);
-			}
-		});
-	}
-
 	// items problems
 	if (options.allowed_ui_latest_data && options.items.length) {
 		const history = [];
@@ -760,7 +786,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 				label: item.name,
 				url: url.getUrl()
 			});
-		};
+		}
 
 		items.push({
 			label: t('History'),
@@ -775,33 +801,74 @@ function getMenuPopupTrigger(options, trigger_element) {
 		});
 	}
 
+	if ('show_update_problem' in options && options.show_update_problem) {
+		url = new Curl('zabbix.php');
+		url.setArgument('action', 'popup');
+		url.setArgument('popup', 'acknowledge.edit');
+		url.setArgument('eventid', options.eventid);
+
+		sections.push({
+			label: t('Actions'),
+			items: [{
+				label: t('Update problem'),
+				clickCallback: function() {
+					jQuery(this).closest('.menu-popup-top').menuPopup('close', null);
+				},
+				url: url.getUrl(),
+				dataAttributes: {
+					action: 'acknowledge.edit',
+					eventid: options.eventid
+				}
+			}]
+		});
+	}
+
 	// configuration
 	if (options.allowed_ui_conf_hosts) {
 		const config_urls = [];
 		const item_urls = [];
 
-		url = new Curl('triggers.php');
-		url.setArgument('form', 'update');
-		url.setArgument('triggerid', options.triggerid);
+		url = new Curl('zabbix.php');
+		url.setArgument('action', 'popup');
+		url.setArgument('popup', 'trigger.edit');
 		url.setArgument('context', 'host');
+		url.setArgument('triggerid', options.triggerid);
 
 		config_urls.push({
 			label: t('Trigger'),
-			url: url.getUrl()
+			url: url.getUrl(),
+			dataAttributes: {
+				action: 'trigger.edit',
+				triggerid: options.triggerid,
+				context: 'host'
+			}
 		});
 
 		if (options.items.length) {
 			for (const item of options.items) {
-				url = new Curl('items.php');
-				url.setArgument('form', 'update');
-				url.setArgument('itemid', item.params.itemid);
-				url.setArgument('context', 'host');
+				if (item.params.is_webitem) {
+					item_urls.push({
+						label: item.name,
+						disabled: true
+					});
+				}
+				else {
+					url = new Curl('zabbix.php');
+					url.setArgument('action', 'popup');
+					url.setArgument('popup', 'item.edit');
+					url.setArgument('context', 'host');
+					url.setArgument('itemid', item.params.itemid);
 
-				item_urls.push({
-					label: item.name,
-					disabled: item.params.is_webitem,
-					url: url.getUrl()
-				});
+					item_urls.push({
+						label: item.name,
+						url: url.getUrl(),
+						dataAttributes: {
+							action: 'item.edit',
+							itemid: item.params.itemid,
+							context: 'host'
+						}
+					});
+				}
 			}
 
 			config_urls.push({
@@ -826,8 +893,8 @@ function getMenuPopupTrigger(options, trigger_element) {
 		curl.setArgument('action', 'popup.acknowledge.create');
 
 		/*
-		 * Some widgets cannot show symptoms. So it is not possible to convert to symptoms cause if only cause evets are
-		 * displayed.
+		 * Some widgets cannot show symptoms. So it is not possible to convert to symptoms cause if only cause events
+		 * are displayed.
 		 */
 		if (typeof options.show_rank_change_cause !== 'undefined' && options.show_rank_change_cause) {
 			// Must be synced with PHP ZBX_PROBLEM_UPDATE_RANK_TO_CAUSE.
@@ -844,7 +911,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 						body: urlEncodeData({
 							eventids: [options.eventid],
 							change_rank: ZBX_PROBLEM_UPDATE_RANK_TO_CAUSE,
-							_csrf_token: options.csrf_tokens['acknowledge']
+							[CSRF_TOKEN_NAME]: options.csrf_tokens['acknowledge']
 						})
 					})
 						.then((response) => response.json())
@@ -892,7 +959,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 							eventids: options.eventids,
 							cause_eventid: options.eventid,
 							change_rank: ZBX_PROBLEM_UPDATE_RANK_TO_SYMPTOM,
-							_csrf_token: options.csrf_tokens['acknowledge']
+							[CSRF_TOKEN_NAME]: options.csrf_tokens['acknowledge']
 						})
 					})
 						.then((response) => response.json())
@@ -938,7 +1005,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 	if ('urls' in options) {
 		sections.push({
 			label: t('Links'),
-			items: getMenuPopupURLData(options.urls, trigger_element)
+			items: getMenuPopupURLData(options.urls, trigger_element, null, options.eventid)
 		});
 	}
 
@@ -1030,36 +1097,80 @@ function getMenuPopupItem(options) {
 		const config_urls = [];
 		const config_triggers = {
 			label: t('Triggers'),
-			disabled: options.triggers.length === 0
+			disabled: options.binary_value_type || options.triggers.length === 0
 		};
 
 		if (options.isWriteable) {
-			url = new Curl('items.php');
-			url.setArgument('form', 'update');
-			url.setArgument('hostid', options.hostid);
-			url.setArgument('itemid', options.itemid);
-			url.setArgument('backurl', options.backurl);
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'popup');
+			url.setArgument('popup', 'item.edit');
 			url.setArgument('context', options.context);
+			url.setArgument('itemid', options.itemid);
 
 			config_urls.push({
 				label: t('Item'),
-				url: url.getUrl()
+				url: url.getUrl(),
+				class: 'js-item-edit',
+				dataAttributes: {
+					action: 'item.edit',
+					context: options.context,
+					itemid: options.itemid
+				}
 			});
 		}
 
-		if (options.triggers.length) {
+		if (options.context === 'host') {
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'popup');
+			url.setArgument('popup', 'host.edit');
+			url.setArgument('hostid', options.hostid);
+
+			config_urls.push({
+				label: t('Host'),
+				disabled: !options.isWriteable,
+				url: url.getUrl(),
+				dataAttributes: {
+					action: 'host.edit',
+					hostid: options.hostid,
+				}
+			});
+		}
+		else {
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'popup');
+			url.setArgument('popup', 'template.edit');
+			url.setArgument('templateid', options.hostid);
+
+			config_urls.push({
+				label: t('Template'),
+				url: url.getUrl(),
+				dataAttributes: {
+					action: 'template.edit',
+					templateid: options.hostid,
+				}
+			});
+		}
+
+		if (!config_triggers.disabled) {
 			const trigger_items = [];
 
 			for (const value of options.triggers) {
-				url = new Curl('triggers.php');
-				url.setArgument('form', 'update');
+				url = new Curl('zabbix.php');
+				url.setArgument('action', 'popup');
+				url.setArgument('popup', 'trigger.edit');
 				url.setArgument('triggerid', value.triggerid);
-				url.setArgument('backurl', options.backurl);
+				url.setArgument('hostid', options.hostid);
 				url.setArgument('context', options.context);
 
 				trigger_items.push({
 					label: value.description,
-					url: url.getUrl()
+					url: url.getUrl(),
+					dataAttributes: {
+						action: 'trigger.edit',
+						triggerid: value.triggerid,
+						hostid: options.hostid,
+						context: options.context
+					}
 				});
 			}
 
@@ -1068,32 +1179,40 @@ function getMenuPopupItem(options) {
 
 		config_urls.push(config_triggers);
 
-		url = new Curl('triggers.php');
-		url.setArgument('form', 'create');
-		url.setArgument('hostid', options.hostid);
-		url.setArgument('description', options.name);
-		url.setArgument('expression', 'func(/' + options.host + '/' + options.key + ')');
-		url.setArgument('backurl', options.backurl);
-		url.setArgument('context', options.context);
-
 		config_urls.push({
 			label: t('Create trigger'),
-			url: url.getUrl()
+			disabled: options.binary_value_type,
+			clickCallback: function(e) {
+				jQuery(this).closest('.menu-popup').menuPopup('close', null);
+
+				window.popupManagerInstance.openPopup('trigger.edit', {
+					hostid: options.hostid,
+					name: options.name,
+					expression: 'func(/' + options.host + '/' + options.key + ')',
+					context: options.context
+				});
+			}
 		});
 
-		url = new Curl('items.php');
-		url.setArgument('form', 'create');
-		url.setArgument('hostid', options.hostid);
-		url.setArgument('type', 18); // ITEM_TYPE_DEPENDENT
-		url.setArgument('master_itemid', options.itemid);
-		url.setArgument('backurl', options.backurl);
-		url.setArgument('context', options.context);
-
-		config_urls.push({
-			label: t('Create dependent item'),
-			url: url.getUrl(),
-			disabled: options.isDiscovery
-		});
+		if (options.isDiscovery) {
+			config_urls.push({
+				label: t('Create dependent item'),
+				disabled: true
+			});
+		}
+		else {
+			config_urls.push({
+				label: t('Create dependent item'),
+				clickCallback: () => {
+					window.popupManagerInstance.openPopup('item.edit', {
+						context: options.context,
+						hostid: options.hostid,
+						master_itemid: options.itemid,
+						type: 18 // ITEM_TYPE_DEPENDENT
+					});
+				}
+			});
+		}
 
 		url = new Curl('host_discovery.php');
 		url.setArgument('form', 'create');
@@ -1116,20 +1235,22 @@ function getMenuPopupItem(options) {
 	}
 
 	if (options.context !== 'template') {
-		const execute = {
-			label: t('Execute now'),
-			disabled: !options.isExecutable
-		};
-
 		if (options.isExecutable) {
-			execute.clickCallback = function() {
-				jQuery(this).closest('.menu-popup').menuPopup('close', null);
+			actions.push({
+				label: t('Execute now'),
+				clickCallback: function() {
+					jQuery(this).closest('.menu-popup').menuPopup('close', null);
 
-				view.checkNow(options.itemid);
-			};
+					view.executeNow(null, {itemids: [options.itemid]});
+				}
+			})
+		}
+		else {
+			actions.push({
+				label: t('Execute now'),
+				disabled: true
+			});
 		}
-
-		actions.push(execute);
 
 		sections.push({
 			label: t('Actions'),
@@ -1164,33 +1285,43 @@ function getMenuPopupItemPrototype(options) {
 		disabled: true
 	};
 
-	let url;
-
-	url = new Curl('disc_prototypes.php');
-	url.setArgument('form', 'update');
-	url.setArgument('parent_discoveryid', options.parent_discoveryid);
-	url.setArgument('itemid', options.itemid);
+	const url = new Curl('zabbix.php');
+	url.setArgument('action', 'popup');
+	url.setArgument('popup', 'item.prototype.edit');
 	url.setArgument('context', options.context);
+	url.setArgument('itemid', options.itemid);
+	url.setArgument('parent_discoveryid', options.parent_discoveryid);
 
 	config_urls.push({
 		label: t('Item prototype'),
-		url: url.getUrl()
+		url: url.getUrl(),
+		dataAttributes: {
+			action: 'item.prototype.edit',
+			context: options.context,
+			itemid: options.itemid,
+			parent_discoveryid: options.parent_discoveryid
+		}
 	});
 
 	if (options.trigger_prototypes.length) {
 		const trigger_prototypes = [];
 
 		for (const value of options.trigger_prototypes) {
-			url = new Curl('trigger_prototypes.php');
-			url.setArgument('form', 'update');
-			url.setArgument('parent_discoveryid', options.parent_discoveryid);
-			url.setArgument('triggerid', value.triggerid)
+			url.setArgument('action', 'popup');
+			url.setArgument('popup', 'trigger.prototype.edit');
 			url.setArgument('context', options.context);
-			url.setArgument('backurl', options.backurl);
+			url.setArgument('triggerid', value.triggerid);
+			url.setArgument('parent_discoveryid', options.parent_discoveryid);
 
 			trigger_prototypes.push({
 				label: value.description,
-				url: url.getUrl()
+				url: url.getUrl(),
+				dataAttributes: {
+					action: 'trigger.prototype.edit',
+					context: options.context,
+					triggerid: value.triggerid,
+					parent_discoveryid: options.parent_discoveryid
+				}
 			});
 		}
 
@@ -1201,29 +1332,32 @@ function getMenuPopupItemPrototype(options) {
 
 	config_urls.push(config_triggers);
 
-	url = new Curl('trigger_prototypes.php');
-	url.setArgument('parent_discoveryid', options.parent_discoveryid);
-	url.setArgument('form', 'create');
-	url.setArgument('description', options.name);
-	url.setArgument('expression', 'func(/' + options.host + '/' + options.key + ')');
-	url.setArgument('context', options.context);
-	url.setArgument('backurl', options.backurl);
-
 	config_urls.push({
 		label: t('Create trigger prototype'),
-		url: url.getUrl()
-	});
+		clickCallback: function(e) {
+			e.preventDefault();
+			jQuery(this).closest('.menu-popup').menuPopup('close', null);
 
-	url = new Curl('disc_prototypes.php');
-	url.setArgument('form', 'create');
-	url.setArgument('parent_discoveryid', options.parent_discoveryid);
-	url.setArgument('type', 18);	// ITEM_TYPE_DEPENDENT
-	url.setArgument('master_itemid', options.itemid);
-	url.setArgument('context', options.context);
+			window.popupManagerInstance.openPopup('trigger.prototype.edit', {
+				parent_discoveryid: options.parent_discoveryid,
+				name: options.name,
+				hostid: options.hostid,
+				expression: 'func(/' + options.host + '/' + options.key + ')',
+				context: options.context
+			});
+		}
+	});
 
 	config_urls.push({
 		label: t('Create dependent item'),
-		url: url.getUrl()
+		clickCallback: () => {
+			window.popupManagerInstance.openPopup('item.prototype.edit', {
+				context: options.context,
+				master_itemid: options.itemid,
+				parent_discoveryid: options.parent_discoveryid,
+				type: 18 // ITEM_TYPE_DEPENDENT
+			});
+		}
 	});
 
 	sections.push({
@@ -1365,6 +1499,7 @@ function getMenuPopupTriggerMacro(options) {
 				expressionInput.val(expression.string);
 
 				jQuery(this).closest('.menu-popup').menuPopup('close', null);
+				document.getElementById('expr_temp').dispatchEvent(new Event('change'));
 			}
 		};
 	});
@@ -1378,7 +1513,7 @@ function getMenuPopupTriggerMacro(options) {
 /**
  * Build script menu tree.
  *
- * @param {array}  scripts            Script names and nenu paths.
+ * @param {array}  scripts            Script names and menu paths.
  * @param {Node}   trigger_element    UI element which triggered opening of overlay dialogue.
  * @param {array}  hostid             Host ID.
  * @param {array}  eventid            Event ID.
@@ -1400,7 +1535,12 @@ function getMenuPopupScriptData(scripts, trigger_element, hostid, eventid, csrf_
 				scriptid: script.scriptid,
 				confirmation: script.confirmation,
 				hostid: hostid,
-				eventid: eventid
+				eventid: eventid,
+				manualinput: script.manualinput,
+				manualinput_prompt: script.manualinput_prompt,
+				manualinput_validator_type: script.manualinput_validator_type,
+				manualinput_validator: script.manualinput_validator,
+				manualinput_default_value: script.manualinput_default_value
 			});
 		}
 	}
@@ -1411,12 +1551,14 @@ function getMenuPopupScriptData(scripts, trigger_element, hostid, eventid, csrf_
 /**
  * Build URL menu tree.
  *
- * @param {array} urls             URL names and nenu paths.
- * @param {Node}  trigger_element  UI element which triggered opening of overlay dialogue.
+ * @param {array}        urls             URL names and menu paths.
+ * @param {Node}         trigger_element  UI element which triggered opening of overlay dialogue.
+ * @param {string|null}  hostid           ID of host which triggered opening of overlay dialogue.
+ * @param {string|null}  eventid          ID of event which triggered opening of overlay dialogue.
  *
  * @return {array}
  */
-function getMenuPopupURLData(urls, trigger_element) {
+function getMenuPopupURLData(urls, trigger_element, hostid, eventid) {
 	let tree = {};
 
 	// Parse URLs and create tree.
@@ -1430,7 +1572,14 @@ function getMenuPopupURLData(urls, trigger_element) {
 				url: url.url,
 				target: url.target,
 				confirmation: url.confirmation,
-				rel: url.rel,
+				manualinput: url.manualinput,
+				manualinput_prompt: url.manualinput_prompt,
+				manualinput_validator_type: url.manualinput_validator_type,
+				manualinput_validator: url.manualinput_validator,
+				manualinput_default_value: url.manualinput_default_value,
+				scriptid: url.scriptid,
+				hostid,
+				eventid
 			});
 		}
 	}
@@ -1471,8 +1620,8 @@ function appendTreeItem(tree, name, items, params) {
 /**
  * Build URL menu items from tree.
  *
- * @param {object} tree        Menu tree object to where menu items are.
- * @param {Node}   trigger_elm UI element which triggered opening of overlay dialogue.
+ * @param {object} tree         Menu tree object to where menu items are.
+ * @param {Node}   trigger_elm  UI element which triggered opening of overlay dialogue.
  *
  * @return {array}
  */
@@ -1483,19 +1632,27 @@ function getMenuPopupURLItems(tree, trigger_elm) {
 		Object.values(tree).map((data) => {
 			const item = {label: data.name};
 
-			if (typeof data.items !== 'undefined' && objectSize(data.items) > 0) {
+			if (data.items !== undefined && objectSize(data.items) > 0) {
 				item.items = getMenuPopupURLItems(data.items, trigger_elm);
 			}
 
-			if (typeof data.params !== 'undefined') {
-				item.url = data.params.url;
-				item.target = data.params.target;
-				item.rel = data.params.rel;
-
-				if (data.params.confirmation !== '') {
+			if (data.params !== undefined) {
+				if (data.params.scriptid !== undefined) {
 					item.clickCallback = function(e) {
-						return confirm(data.params.confirmation);
-					}
+						jQuery(this)
+							.closest('.menu-popup-top')
+							.menuPopup('close', trigger_elm, false);
+						Script.openUrl(data.params.scriptid, data.params.confirmation, trigger_elm,
+							data.params.hostid, data.params.eventid, data.params.url, data.params.target,
+							data.params.manualinput, data.params.manualinput_prompt,
+							data.params.manualinput_validator_type, data.params.manualinput_validator,
+							data.params.manualinput_default_value
+						);
+						cancelEvent(e);
+					};
+				}
+				else {
+					item.url = data.params.url;
 				}
 			}
 
@@ -1522,17 +1679,19 @@ function getMenuPopupScriptItems(tree, trigger_elm, csrf_token) {
 		Object.values(tree).map((data) => {
 			const item = {label: data.name};
 
-			if (typeof data.items !== 'undefined' && objectSize(data.items) > 0) {
+			if (data.items !== undefined && objectSize(data.items) > 0) {
 				item.items = getMenuPopupScriptItems(data.items, trigger_elm, csrf_token);
 			}
 
-			if (typeof data.params !== 'undefined' && typeof data.params.scriptid !== 'undefined') {
+			if (data.params !== undefined && data.params.scriptid !== undefined) {
 				item.clickCallback = function(e) {
 					jQuery(this)
 						.closest('.menu-popup-top')
 						.menuPopup('close', trigger_elm, false);
-					executeScript(data.params.scriptid, data.params.confirmation, trigger_elm, data.params.hostid,
-						data.params.eventid, csrf_token
+					Script.execute(data.params.scriptid, data.params.confirmation, trigger_elm, data.params.hostid,
+						data.params.eventid, csrf_token, data.params.manualinput, data.params.manualinput_prompt,
+						data.params.manualinput_validator_type, data.params.manualinput_validator,
+						data.params.manualinput_default_value
 					);
 					cancelEvent(e);
 				};
@@ -1545,6 +1704,41 @@ function getMenuPopupScriptItems(tree, trigger_elm, csrf_token) {
 	return items;
 }
 
+/**
+ * Get menu structure for discovery rules.
+ *
+ * @param {array}  options                            An array of options for discovery rule menu popup.
+ * @param {string} options['druleid']                 Discovery rule ID.
+ * @param {bool}   options['allowed_ui_conf_drules']  Whether user has access to discovery rules configuration page.
+ *
+ * @return {array}
+ */
+function getMenuPopupDRule(options) {
+	const sections = [];
+	const config_urls = [];
+
+	const url = new Curl('zabbix.php');
+	url.setArgument('action', 'popup');
+	url.setArgument('popup', 'discovery.edit');
+	url.setArgument('druleid', options.druleid);
+
+	config_urls.push({
+		label: t('Discovery rule'),
+		url: url.getUrl(),
+		dataAttributes: {
+			action: 'discovery.edit',
+			druleid: options.druleid
+		}
+	});
+
+	sections.push({
+		label: t('Configuration'),
+		items: config_urls
+	});
+
+	return sections;
+}
+
 jQuery(function($) {
 
 	/**
@@ -1655,11 +1849,11 @@ jQuery(function($) {
 
 			$opener.attr('aria-expanded', 'true');
 
-			var $menu_popup = $('<ul>', {
-					'role': 'menu',
-					'class': 'menu-popup menu-popup-top',
-					'tabindex': 0
-				});
+			let $menu_popup = $('<ul>', {
+				'role': 'menu',
+				'class': 'menu-popup menu-popup-top',
+				'tabindex': 0
+			});
 
 			// Add custom class, if specified.
 			if ('class' in options) {
@@ -1675,10 +1869,11 @@ jQuery(function($) {
 			$menu_popup.data('menu_popup', options);
 
 			if (options.background_layer) {
-				$('.wrapper').append($('<div>', {class: 'menu-popup-overlay'}));
+				$('.wrapper').append($('<div>', {class: 'menu-popup-overlay'}).append($menu_popup));
+			}
+			else {
+				$('.wrapper').append($menu_popup);
 			}
-
-			$('.wrapper').append($menu_popup);
 
 			// Position the menu (before hiding).
 			$menu_popup.position(options.position);
@@ -1726,10 +1921,11 @@ jQuery(function($) {
 				}
 
 				if (options.background_layer) {
-					menu_popup.prev().remove();
+					$('.menu-popup-overlay').remove();
+				}
+				else {
+					menu_popup.remove();
 				}
-
-				menu_popup.remove();
 
 				// Call menu close callback function.
 				typeof options.closeCallback === 'function' && options.closeCallback.apply();
@@ -1996,7 +2192,7 @@ jQuery(function($) {
 		}
 
 		if (options.selected) {
-			link.addClass('selected');
+			link.addClass(['selected', ZBX_ICON_CHECK]);
 		}
 
 		if (options.class) {
